#! /usr/bin/perl
#**********************************************************************
#* (C) Copyright IBM Corporation 2004, 2004.  All rights reserved.    *
#>                                                                    *
#* Tivoli Storage Manager                                             *
#*                                                                    *
#* This script displays the average full volume capacity by storage   *
#* pool for all sequential storage pools.  The average full volume    *
#* capacity depends on the type of storage device and the type of     *
#* data stored (compressibility).  This information is useful for     *
#* determining how much data needs to be included in a collocation    *
#* group to optimally use the storage media volumes.                  *
#*                                                                    *
#* Usage: fullvolcapacity -ID=userid -PAssword=password               *
#*                                                                    *
#*        where -ID=userid specifies the administrator's user ID      *
#*              -PAssword=password specifies the administrator's      *
#*                 password                                           *
#*                                                                    *
#* Dependencies: UNIX or Windows                                      *
#*               Perl interpreter installed                           *
#*               TSM administrative client installed and configured   *
#>                                                                    *
#* Note: This sample script is shipped "AS-IS" with all TSM server    *
#* platforms and must remain formatted with lines less than 80        *
#* characters each.                                                   *
#*                                                                    *
#**********************************************************************
use strict;
if ( @ARGV == 0 ) { usage() }

my $Id = "";
my $Pa = "";
while ( substr( $ARGV[0], 0, 1 ) eq "-" ) {
   my $A = uc( $ARGV[0] );
   if ( chkarg( $A, "-ID", 3 ) )       { $Id = $ARGV[0]; shift; next; }
   if ( chkarg( $A, "-PASSWORD", 3 ) ) { $Pa = $ARGV[0]; shift; next; }
   if ( $ARGV[0] eq "-h" ) { usage() }
   print "Syntax error: Argument $ARGV[0] not understood.\n"; shift;
}

if ( $Id eq '' ) {
   print "Syntax error: TSM administrator's user ID must be supplied.\n";
   usage();
   exit;
}
if ( $Pa eq '' ) {
   print "Syntax error: TSM administrator's password must be supplied.\n";
   usage();
   exit;
}
if ( @ARGV > 0 ) {
   print "Syntax error: Extraneous arguments supplied.\n";
   usage();
   exit;
}

open  MACRO, ">_fvolcap.mac" or die;
print MACRO  'select stgpool_name as "Storage Pool",';
print MACRO  ' devclass_name as "Device Class",';
print MACRO  ' count(*) as "Number of Full Volumes",';
print MACRO  ' cast(avg(pct_utilized) as decimal(8,1))';
print MACRO  ' as "Average Pct Utilized",';
print MACRO  ' cast(avg(est_capacity_mb) as decimal(18,0))';
print MACRO  ' as "Average Full Volume Capacity in MB" from volumes';
print MACRO  " where status='FULL' and devclass_name<>'DISK'";
print MACRO  " group by stgpool_name, devclass_name\n";
close MACRO;

system "dsmadmc $Id $Pa -displaymode=list macro _fvolcap.mac";
unlink "_fvolcap.mac";
exit;

sub usage
#**********************************************************************
#* Display program usage information by reading program code header   *
#*                                                                    *
#**********************************************************************
{
   my $Skip = 1;
   open USAGE, "<$0";
   while ( <USAGE> ) {
      if ( substr( $_, 0, 2 ) eq "#>" ) {
         if ( $Skip == 1 ) { $Skip = 0 }
         else              { last }
      }
      if ( $Skip == 0 ) { chop; chop; print substr( $_, 3 )."\n" }
   }
   close USAGE;
   exit 4;
}

sub chkarg
#**********************************************************************
#* Check supplied userid and password arguments                       *
#*                                                                    *
#**********************************************************************
{
   my ( $Arg, $Flag, $Length ) = @_;
   my @Arg = split "=", $Arg;
   if ( length( $Arg[0] ) > $Length ) { $Length = length( $Arg[0] ) }
   if ( $Arg[0] eq substr( $Flag, 0, $Length ) and $Arg[1] ne '' ) {
      return 1;
   }
   else {
      return 0;
   }
}
